==> kdocker-4.2.2.1.tar.gz: kdocker-4.2.2.1/i18n/kdocker_it_IT.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it_IT">
<context>
    <name>KDocker</name>
    <message>
        <location filename="../src/kdocker.cpp" line="219"/>
        <source>Usage: %1 [options] [command] -- [command options]</source>
        <translation>Uso: %1 [opzioni] [comando] -- [opzioni comando]</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="220"/>
        <source>Docks any application into the system tray</source>
        <translation>Aggancia al vassoio di sistema qualsiasi applicazione</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="222"/>
        <source>Command</source>
        <translation>Comando</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="223"/>
        <source>Run command and dock window</source>
        <translation>Esegui comando e aggancia la finestra</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="224"/>
        <source>Use -- after command to specify options for command</source>
        <translation>Usa -- dopo il comando per specificare opzioni aggiuntive</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="226"/>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="227"/>
        <source>Show author information</source>
        <translation>Mostra informazioni sull&apos;autore</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="228"/>
        <source>Don&apos;t warn about non-normal windows (blind mode)</source>
        <translation>Non avvisare in caso di finestre anomale (modalità cieca)</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="229"/>
        <source>Remove the window border</source>
        <translation>Rimuovi il bordo della finestra</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="230"/>
        <source>Maximum time in seconds to allow for command to start and open a window (defaults to 5 sec)</source>
        <translation>Tempo massimo di esecuzione per permettere al comando di aprire una finestra (default 5 secondi)</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="231"/>
        <source>Dock window that has focus (active window)</source>
        <translation>Aggancia la finestra che ha focus (finestra attiva)</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="232"/>
        <source>Display this help</source>
        <translation>Mostra questo aiuto</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="233"/>
        <source>Iconify when focus lost</source>
        <translation>Riduci ad icona quando perde focus</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="234"/>
        <source>Keep application window showing (dont hide on dock)</source>
        <translation>Mantieni in primo piano la finestra (non nascondere quando agganciata)</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="235"/>
        <source>Name used for matching when running command (fall back in case command is a launcher so pid and command won&apos;t match the window tile or class)</source>
        <translation>Nome usato da associare quando si esegue il comando (fall back nel caso in cui il comando sia un launcher quindi pid e comando non corrispondano alla classe o tessera della finestra)</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="236"/>
        <source>Iconify when obscured</source>
        <translation>Riduci ad incona quando oscurato</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="237"/>
        <source>Set ballooning timeout (popup time)</source>
        <translation>Imposta durata fumetto (durata popup)</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="238"/>
        <source>Disable ballooning title changes (quiet)</source>
        <translation>Disabilita modifiche al titolo del fumetto (silenzioso)</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="239"/>
        <source>Remove this application from the pager</source>
        <translation>Rimuovi dal pager questa applicazione</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="240"/>
        <source>Make the window sticky (appears on all desktops)</source>
        <translation>Rendi fissa questa finestra (apparirà su tutti i desktops)</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="241"/>
        <source>Remove this application from the taskbar</source>
        <translation>Rimuovi dalla taskbar questa applicazione</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="242"/>
        <source>Display version</source>
        <translation>Mostra versione</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="243"/>
        <source>Window id of the application to dock</source>
        <translation>Id finestra dell&apos;applicazione da agganciare</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="244"/>
        <source>Process id of the application to dock</source>
        <translation>Id processo dell&apos;applicazione da agganciare</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="245"/>
        <source>Force matching of command by using name instead of pid</source>
        <translation>Forza il comando ad utlizzare il nome anzichè il pid</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="247"/>
        <source>Bugs and wishes to https://bugs.launchpad.net/kdocker</source>
        <translation>Bugs e suggerimenti a https://bugs.launchpad.net/kdocker</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="248"/>
        <source>Project information at https://launchpad.net/kdocker</source>
        <translation>Informazioni sul progetto disponibili all&apos;indirizzo https://bugs.launchpad.net/kdocker</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="253"/>
        <source>Usage: %1 [options] command</source>
        <translation>Uso: %1 [opzioni] comando</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="254"/>
        <source>Try `%1 -h&apos; for more information</source>
        <translation>Prova `%1 -h&apos; per aver maggiorni informazioni</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="259"/>
        <source>%1 version: %2</source>
        <translation>%1 versione %2</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="260"/>
        <source>Using Qt version: %1</source>
        <translation>Versione Qt in uso: %1</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/constants.h" line="35"/>
        <source>KDocker will help you dock any application into the system tray. This means you can dock openoffice, xmms, firefox, thunderbird, anything! Just point and click. Works for all NET WM compliant window managers - that includes KDE, GNOME, Xfce, Fluxbox and many more.

Created by %1. Updated and maintained by %2.</source>
        <translation>KDocker ti permetterà di ridurre ad icona nel vassoio di sistema qualsiasi applicazione. Questo significa che potrai ridurre ad icona openoffice, xmms, firefox, thunderbird, qualsiasi cosa! Semplicemente puntando e cliccando. Funziona con tutti i window managers conformi a NET WM come KDE, GNOME, Xfce, Fluxbox e molti altri ancora.

Creato da %1. Aggiornato e mantenuto da: %2.</translation>
    </message>
</context>
<context>
    <name>Scanner</name>
    <message>
        <location filename="../src/scanner.cpp" line="93"/>
        <source>KDocker</source>
        <translation>KDocker</translation>
    </message>
    <message>
        <location filename="../src/scanner.cpp" line="64"/>
        <source>%1 did not start properly.</source>
        <translation>%1 non è stato avviato correttamente.</translation>
    </message>
    <message>
        <location filename="../src/scanner.cpp" line="93"/>
        <source>Could not find a matching window for %1 in the specified time: %2 seconds.</source>
        <translation>Impossibile trovare una finestra corrispondente per %1 nel lasso di tempo specificato: %2 secondi.</translation>
    </message>
</context>
<context>
    <name>TrayItem</name>
    <message>
        <location filename="../src/trayitem.cpp" line="273"/>
        <source>Select Icon</source>
        <translation>Seleziona Icona</translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="351"/>
        <source>About %1 - %2</source>
        <translation>A proposito di %1 - %2</translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="353"/>
        <source>See %1 for more information.</source>
        <translation>Consulta %1 per maggiori informazioni.</translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="484"/>
        <source>Show %1</source>
        <translation>Mostra %1</translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="487"/>
        <source>Hide %1</source>
        <translation>Nascondi %1</translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="497"/>
        <source>About %1</source>
        <translation>A proposito di %1</translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="501"/>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="502"/>
        <source>Set icon</source>
        <translation>Imposta icona</translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="505"/>
        <source>Skip taskbar</source>
        <translation>Salta taskbar</translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="510"/>
        <source>Skip pager</source>
        <translation>Salta pager</translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="515"/>
        <source>Sticky</source>
        <translation>Fissa</translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="520"/>
        <source>Iconify when minimized</source>
        <translation>Riduci ad icona quando minimizzata</translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="525"/>
        <source>Iconify when obscured</source>
        <translation>Riduci ad icona quando oscurata</translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="530"/>
        <source>Iconify when focus lost</source>
        <translation>Riduci ad icona quando perde focus</translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="535"/>
        <source>Balloon title changes</source>
        <translation>Il titolo del fumetto cambia</translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="542"/>
        <source>Dock Another</source>
        <translation>Aggancia un&apos;altra</translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="543"/>
        <source>Undock All</source>
        <translation>Sgancia tutti</translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="545"/>
        <source>Toggle</source>
        <translation>Commuta</translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="548"/>
        <source>Undock</source>
        <translation>Sgancia</translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="549"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
</context>
<context>
    <name>TrayItemManager</name>
    <message>
        <source>KDocker</source>
        <translation type="obsolete">KDocker</translation>
    </message>
    <message>
        <location filename="../src/trayitemmanager.cpp" line="155"/>
        <source>Cannot dock the active window because no window has focus.</source>
        <translation>Impossibile agganciare la finestra attiva perchè priva di focus.</translation>
    </message>
    <message>
        <location filename="../src/trayitemmanager.cpp" line="196"/>
        <source>Invalid window id.</source>
        <translation>Id finestra invalido.</translation>
    </message>
    <message>
        <location filename="../src/trayitemmanager.cpp" line="248"/>
        <source>This window is already docked.
Click on system tray icon to toggle docking.</source>
        <translation>Questa finestra è già agganciata.
Clicca sull&apos;icona corrispondente nel vassoio di sistema per commutare.</translation>
    </message>
    <message>
        <location filename="../src/trayitemmanager.cpp" line="283"/>
        <source>Select the application/window to dock with the left mouse button.</source>
        <translation>Seleziona l&apos;applicazione/finestra da agganciare cliccando con il tasto sinistro del mouse.</translation>
    </message>
    <message>
        <location filename="../src/trayitemmanager.cpp" line="284"/>
        <source>Click any other mouse button to abort.</source>
        <translation>Click con un qualsiasi tasto del mouse per annullare.</translation>
    </message>
    <message>
        <location filename="../src/trayitemmanager.cpp" line="298"/>
        <source>The window you are attempting to dock does not seem to be a normal window.</source>
        <translation>La finestra che stai cercando di agganciare sembra non essere una normale finestra.</translation>
    </message>
</context>
</TS>

==> kdocker_4.5.orig.tar.gz: kdocker-4.5/i18n/kdocker_it_IT.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it_IT">
<context>
    <name>Constants</name>
    <message>
        <location filename="../src/constants.cpp" line="29"/>
        <source>KDocker will help you dock any application into the system tray. This means you can dock openoffice, xmms, firefox, thunderbird, anything! Just point and click. Works for all NET WM compliant window managers - that includes KDE, GNOME, Xfce, Fluxbox and many more.

Created by %1. Updated and maintained by %2.</source>
        <translation>KDocker ti permetterà di ridurre ad icona nel vassoio di sistema qualsiasi applicazione. Questo significa che potrai ridurre ad icona openoffice, xmms, firefox, thunderbird, qualsiasi cosa! Semplicemente puntando e cliccando. Funziona con tutti i window managers conformi a NET WM come KDE, GNOME, Xfce, Fluxbox e molti altri ancora.

Creato da %1. Aggiornato e mantenuto da: %2.</translation>
    </message>
</context>
<context>
    <name>KDocker</name>
    <message>
        <location filename="../src/kdocker.cpp" line="113"/>
        <source>Usage: %1 [options] [command] -- [command options]</source>
        <translation>Uso: %1 [opzioni] [comando] -- [opzioni comando]</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="114"/>
        <source>Docks any application into the system tray</source>
        <translation>Aggancia al vassoio di sistema qualsiasi applicazione</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="116"/>
        <source>Command</source>
        <translation>Comando</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="117"/>
        <source>Run command and dock window</source>
        <translation>Esegui comando e aggancia la finestra</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="118"/>
        <source>Use -- after command to specify options for command</source>
        <translation>Usa -- dopo il comando per specificare opzioni aggiuntive</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="120"/>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="121"/>
        <source>Show author information</source>
        <translation>Mostra informazioni sull&apos;autore</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="122"/>
        <source>Don&apos;t warn about non-normal windows (blind mode)</source>
        <translation>Non avvisare in caso di finestre anomale (modalità cieca)</translation>
    </message>
    <message>
        <source>Remove the window border</source>
        <translation type="obsolete">Rimuovi il bordo della finestra</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="123"/>
        <source>Don&apos;t iconify on close</source>
        <translation>Non ridurre ad icona se chiuso</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="124"/>
        <source>Maximum time in seconds to allow for command to start and open a window (defaults to 5 sec)</source>
        <translation>Tempo massimo di esecuzione per permettere al comando di aprire una finestra (default 5 secondi)</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="125"/>
        <source>Dock window that has focus (active window)</source>
        <translation>Aggancia la finestra che ha focus (finestra attiva)</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="126"/>
        <source>Display this help</source>
        <translation>Mostra questo aiuto</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="127"/>
        <source>Iconify when focus lost</source>
        <translation>Riduci ad icona quando perde focus</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="128"/>
        <source>Keep application window showing (dont hide on dock)</source>
        <translation>Mantieni in primo piano la finestra (non nascondere quando agganciata)</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="129"/>
        <source>Name used for matching when running command (fall back in case command is a launcher so pid and command won&apos;t match the window tile or class)</source>
        <translation>Nome usato da associare quando si esegue il comando (fall back nel caso in cui il comando sia un launcher quindi pid e comando non corrispondano alla classe o tessera della finestra)</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="130"/>
        <source>Iconify when obscured</source>
        <translation>Riduci ad incona quando oscurato</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="131"/>
        <source>Set ballooning timeout (popup time)</source>
        <translation>Imposta durata fumetto (durata popup)</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="132"/>
        <source>Disable ballooning title changes (quiet)</source>
        <translation>Disabilita modifiche al titolo del fumetto (silenzioso)</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="133"/>
        <source>Remove this application from the pager</source>
        <translation>Rimuovi dal pager questa applicazione</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="134"/>
        <source>Make the window sticky (appears on all desktops)</source>
        <translation>Rendi fissa questa finestra (apparirà su tutti i desktops)</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="135"/>
        <source>Remove this application from the taskbar</source>
        <translation>Rimuovi dalla taskbar questa applicazione</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="136"/>
        <source>Display version</source>
        <translation>Mostra versione</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="137"/>
        <source>Window id of the application to dock</source>
        <translation>Id finestra dell&apos;applicazione da agganciare</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="138"/>
        <source>Process id of the application to dock</source>
        <translation>Id processo dell&apos;applicazione da agganciare</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="139"/>
        <source>Force matching of command by using name instead of pid</source>
        <translation>Forza il comando ad utlizzare il nome anzichè il pid</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="141"/>
        <source>Bugs and wishes to https://bugs.launchpad.net/kdocker</source>
        <translation>Bugs e suggerimenti a https://bugs.launchpad.net/kdocker</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="142"/>
        <source>Project information at https://launchpad.net/kdocker</source>
        <translation>Informazioni sul progetto disponibili all&apos;indirizzo https://bugs.launchpad.net/kdocker</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="147"/>
        <source>Usage: %1 [options] command</source>
        <translation>Uso: %1 [opzioni] comando</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="148"/>
        <source>Try `%1 -h&apos; for more information</source>
        <translation>Prova `%1 -h&apos; per aver maggiorni informazioni</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="153"/>
        <source>%1 version: %2</source>
        <translation>%1 versione %2</translation>
    </message>
    <message>
        <location filename="../src/kdocker.cpp" line="154"/>
        <source>Using Qt version: %1</source>
        <translation>Versione Qt in uso: %1</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>KDocker will help you dock any application into the system tray. This means you can dock openoffice, xmms, firefox, thunderbird, anything! Just point and click. Works for all NET WM compliant window managers - that includes KDE, GNOME, Xfce, Fluxbox and many more.

Created by %1. Updated and maintained by %2.</source>
        <translation type="obsolete">KDocker ti permetterà di ridurre ad icona nel vassoio di sistema qualsiasi applicazione. Questo significa che potrai ridurre ad icona openoffice, xmms, firefox, thunderbird, qualsiasi cosa! Semplicemente puntando e cliccando. Funziona con tutti i window managers conformi a NET WM come KDE, GNOME, Xfce, Fluxbox e molti altri ancora.

Creato da %1. Aggiornato e mantenuto da: %2.</translation>
    </message>
</context>
<context>
    <name>Scanner</name>
    <message>
        <location filename="../src/scanner.cpp" line="91"/>
        <source>KDocker</source>
        <translation>KDocker</translation>
    </message>
    <message>
        <location filename="../src/scanner.cpp" line="62"/>
        <source>%1 did not start properly.</source>
        <translation>%1 non è stato avviato correttamente.</translation>
    </message>
    <message>
        <location filename="../src/scanner.cpp" line="91"/>
        <source>Could not find a matching window for %1 in the specified time: %2 seconds.</source>
        <translation>Impossibile trovare una finestra corrispondente per %1 nel lasso di tempo specificato: %2 secondi.</translation>
    </message>
</context>
<context>
    <name>TrayItem</name>
    <message>
        <location filename="../src/trayitem.cpp" line="257"/>
        <source>Select Icon</source>
        <translation>Seleziona Icona</translation>
    </message>
    <message>
        <source>About %1 - %2</source>
        <translation type="obsolete">A proposito di %1 - %2</translation>
    </message>
    <message>
        <source>See %1 for more information.</source>
        <translation type="obsolete">Consulta %1 per maggiori informazioni.</translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="492"/>
        <source>Show %1</source>
        <translation>Mostra %1</translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="489"/>
        <source>Hide %1</source>
        <translation>Nascondi %1</translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="503"/>
        <source>About %1</source>
        <translation>A proposito di %1</translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="507"/>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="509"/>
        <source>Set icon</source>
        <translation>Imposta icona</translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="513"/>
        <source>Skip taskbar</source>
        <translation>Salta taskbar</translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="519"/>
        <source>Skip pager</source>
        <translation>Salta pager</translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="525"/>
        <source>Sticky</source>
        <translation>Fissa</translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="531"/>
        <source>Iconify when minimized</source>
        <translation>Riduci ad icona quando minimizzata</translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="537"/>
        <source>Iconify when obscured</source>
        <translation>Riduci ad icona quando oscurata</translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="543"/>
        <source>Iconify when focus lost</source>
        <translation>Riduci ad icona quando perde focus</translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="549"/>
        <source>Iconify on close</source>
        <translation>Riduci ad icona quando chiuso</translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="555"/>
        <source>Balloon title changes</source>
        <translation>Il titolo del fumetto cambia</translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="562"/>
        <source>Dock Another</source>
        <translation>Aggancia un&apos;altra</translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="563"/>
        <source>Undock All</source>
        <translation>Sgancia tutti</translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="565"/>
        <source>Toggle</source>
        <translation>Commuta</translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="568"/>
        <source>Undock</source>
        <translation>Sgancia</translation>
    </message>
    <message>
        <location filename="../src/trayitem.cpp" line="569"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
</context>
<context>
    <name>TrayItemManager</name>
    <message>
        <source>KDocker</source>
        <translation type="obsolete">KDocker</translation>
    </message>
    <message>
        <location filename="../src/trayitemmanager.cpp" line="129"/>
        <source>Cannot dock the active window because no window has focus.</source>
        <translation>Impossibile agganciare la finestra attiva perchè priva di focus.</translation>
    </message>
    <message>
        <location filename="../src/trayitemmanager.cpp" line="170"/>
        <source>Invalid window id.</source>
        <translation>Id finestra invalido.</translation>
    </message>
    <message>
        <location filename="../src/trayitemmanager.cpp" line="211"/>
        <source>This window is already docked.
Click on system tray icon to toggle docking.</source>
        <translation>Questa finestra è già agganciata.
Clicca sull&apos;icona corrispondente nel vassoio di sistema per commutare.</translation>
    </message>
    <message>
        <location filename="../src/trayitemmanager.cpp" line="250"/>
        <source>Select the application/window to dock with the left mouse button.</source>
        <translation>Seleziona l&apos;applicazione/finestra da agganciare cliccando con il tasto sinistro del mouse.</translation>
    </message>
    <message>
        <location filename="../src/trayitemmanager.cpp" line="251"/>
        <source>Click any other mouse button to abort.</source>
        <translation>Click con un qualsiasi tasto del mouse per annullare.</translation>
    </message>
    <message>
        <location filename="../src/trayitemmanager.cpp" line="265"/>
        <source>The window you are attempting to dock does not seem to be a normal window.</source>
        <translation>La finestra che stai cercando di agganciare sembra non essere una normale finestra.</translation>
    </message>
    <message>
        <location filename="../src/trayitemmanager.cpp" line="299"/>
        <source>About %1 - %2</source>
        <translation>A proposito di %1 - %2</translation>
    </message>
    <message>
        <location filename="../src/trayitemmanager.cpp" line="301"/>
        <source>See %1 for more information.</source>
        <translation>Consulta %1 per maggiori informazioni.</translation>
    </message>
</context>
<context>
    <name>XLibUtil</name>
    <message>
        <location filename="../src/xlibutil.cpp" line="280"/>
        <source>Failed to create XC_draped_box</source>
        <translation>Impossibile creare XC_draped_box</translation>
    </message>
    <message>
        <location filename="../src/xlibutil.cpp" line="285"/>
        <source>Failed to grab mouse</source>
        <translation>Impossibile catturare il mouse</translation>
    </message>
</context>
</TS>
